| Title: | Toolbox for hubverse Continuous Integration |
|---|---|
| Description: | Functions for setting up hubverse Continuous Integration workflows. |
| Authors: | Anna Krystalli [aut, cre] (ORCID: <https://orcid.org/0000-0002-2378-4915>), Nicholas G. Reich [ctb] (ORCID: <https://orcid.org/0000-0003-3503-9899>), Evan L. Ray [ctb], Consortium of Infectious Disease Modeling Hubs [cph] |
| Maintainer: | Anna Krystalli <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-06-02 10:07:21 UTC |
| Source: | https://github.com/hubverse-org/hubCI |
Sets up common continuous integration (CI) workflows for a hub that is hosted on GitHub using GitHub Actions. Available actions are hosted in repository hubverse-org/hubverse-actions The function creates the necessary directories and downloads the requested GitHub Action yaml file.
use_hub_github_action(name, ref = NULL)use_hub_github_action(name, ref = NULL)
name |
Name of workflow, i.e. the name of one of the action repository
directories containing a GitHub Action workflow |
ref |
Desired Git reference, usually the name of a tag ( |
## Not run: use_hub_github_action(name = "validate-submission") ## End(Not run)## Not run: use_hub_github_action(name = "validate-submission") ## End(Not run)